/*********************************************************************************

	Script to create a config file that contains classes for all VBS2 weapon sounds.
	
	The config.cpp will be written to the folder P:\vbs2\customer\other\weaponsounds
	The path P:\vbs2\customer\other\ must exist already, the weaponsounds will be created by the script.
	
	Once the file has been created, pack the weaponsounds folder, 
	and place it into the [VBS2 installation folder]\mycontent\addons directory

	The names of the created sound classes will be the weapon class, preceded by "KRON_",
	e.g. the sound for the M136 is "KRON_M136".
	
	If the weapon has different firing modes with their own sound,
	the firing mode will be added to the class name, separated by a double underscore
	(e.g. the sound for the GAU8's Burst1 mode will be "KRON_GAU8__Burst1")
	Only firing modes with unique sounds are added (i.e. if there are several modes,
	all having the same sound, then there will only be a sound class created for the first one.)
	
	The sounds can be played via playSound or say (e.g. playSound "KRON_M136")
	
*********************************************************************************/

// file access function
_output = {
	private ['_path','_line','_action','_status','_ok'];
	_path = _this select 0;
	_line = _this select 1;
	_action = _this select 2;
	
	if (_line=='') then {
		_status = pluginFunction ['VBSPluginFileAccess',format['%1(%2)',_action,_path]];
	} else {
		_status = pluginFunction ['VBSPluginFileAccess',format['%1(%2)@%3',_action,_path,_line]];
	};
};

clearRadio;

// create sound config folder & file
_path = 'P:\vbs2\customer\other\weaponsounds';
_filepath = _path + '\config.cpp';
// first create the directory,
[_path,'','CreateDir'] call _output;
// then create the file
[_filepath,'','Write'] call _output;
[_filepath,'','AppendLine'] call _output;


// write the config header
[_filepath,'class CfgPatches {','AppendLine'] call _output;
[_filepath,'	class KRON_WeaponSounds {','AppendLine'] call _output;
[_filepath,'		units[]={};','AppendLine'] call _output;
[_filepath,'		weapons[]={};','AppendLine'] call _output;
[_filepath,'		requiredVersion=1.0;','AppendLine'] call _output;
[_filepath,'	};','AppendLine'] call _output;
[_filepath,'};','AppendLine'] call _output;
[_filepath,' ','AppendLine'] call _output;
[_filepath,'class CfgSounds {','AppendLine'] call _output;


// create sound class
_writeSound = {
	private ["_path","_type","_config","_property","_configBase","_class","_name","_namebase","_sound","_newsound"];
	_path = _this select 0;
	_type = _this select 1;
	_config = _this select 2;
	_property = _this select 3;
	_configBase = _this select 4;

	if !(isArray (_config >> _property)) exitWith {};
	
	// normally use the weapon's class name as the sound class name
	_class = configName _config;
	// get the weapon's displayName
	_name = getText(_config>>"displayName");
	if (_name=="") then {
		_name = _class;
	};

	// if it's a sub-class, then add it to the class name 
	if (_configBase!="") then {
		// for ammo, add the property name instead (soundFly or soundEngine)
		if (_property!="sound") then {
			_class = _property;
		};
		// find the displayName for the class its inheriting from
		_namebase = getText (configFile>>"CfgWeapons">>_configBase>>"displayName");
		if (_namebase=="") then {
			_namebase = _configBase;
		};
		_name = format["%1 - %2",_namebase,_class];
		_class = format["%1__%2",_configBase,_class];
	};
	// get the sound array, and check whether it's different from the last one
	_sound = getArray (_config >> _property);
	_newsound = ((_configBase!=lastclass) || (_sound select 0!=lastsound));

	// if we have a sound, and it's new, create a class for it
	if ((count _sound==3) && (_sound select 0!='') && _newsound) then {
		[_path,format['	class KRON_%1 {',_class],'AppendLine'] call _output;
		[_path,format['		name = "%1: %2";',_type,_name],'AppendLine'] call _output;
		[_path,format['		sound[]={"%1",%2,%3};',_sound select 0,1,_sound select 2],'AppendLine'] call _output;
		[_path,'		titles[]={};','AppendLine'] call _output;
		[_path,'	};','AppendLine'] call _output;
		lastsound = _sound select 0;
		soundcount = soundcount + 1;
	};
	lastclass = _configBase;
};


// go through all the weapons & ammo classes
{
	_file = _x select 0;
	_configFile = configFile >> format["Cfg%1",_x select 0];
	_properties = _x select 1;
	player sidechat format["Checking Cfg%1",_file];
	sleep .2;
	
	lastsound = "";
	lastclass = "";
	soundcount = 0;
	for '_i' from 0 to (count _configFile)-1 do {
		_config = _configFile select _i;
		if (isClass _config) then {
			{
				if (_file=="Weapons") then {
					// first get the main entry (for "sound")
					[_filepath,_file,_config,_x,""] call _writeSound;
					// then check if the weapon has sub-classes (e.g. for firing modes), and add those as well
					for "_j" from 0 to (count _config)-1 do {
						_configEntry = _config select _j;
						if (isClass _configEntry) then {
							[_filepath,_file,_configEntry,_x,configName _config] call _writeSound;
						};
					};
				} else {
					// first get the main entry (for "soundFly" or "soundEngine")
					[_filepath,_file,_config,_x,configName _config] call _writeSound;
				};
			}forEach _properties;
		};
	};
	player sidechat format["%1 %2 sound classes created",soundcount,_file];
}forEach [
	["Weapons",["sound"]],
	["Ammo",["soundFly","soundEngine"]]
];
	

// close the CfgSouns class
[_filepath,'};','AppendLine'] call _output;

// open the created config file
openURL (_filepath);
